Package: ggrepel
Version: 0.8.0
Authors@R: c(
    person("Kamil", "Slowikowski", email = "kslowikowski@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0002-2843-6370")),
    person("Alicia", "Schep", role = "ctb", comment = c(ORCID = "0000-0002-3915-0618")),
    person("Sean", "Hughes", role = "ctb"),
    person("Saulius", "Lukauskas", role = "ctb"),
    person("Jean-Olivier", "Irisson", role = "ctb", comment = c(ORCID = "0000-0003-4920-3880")),
    person("Zhian N", "Kamvar", role = "ctb", comment = c(ORCID = "0000-0003-1458-7108")),
    person("Thompson", "Ryan", role = "ctb", comment = c(ORCID = "0000-0002-0450-8181")),
    person("Dervieux", "Christophe", role = "ctb", comment = c(ORCID = "0000-0003-4474-2498")),
    person("Yutani", "Hiroaki", role = "ctb"),
    person("Pierre", "Gramme", role = "ctb")
    )
Title: Automatically Position Non-Overlapping Text Labels with
        'ggplot2'
Description: Provides text and label geoms for 'ggplot2' that help to avoid
    overlapping text labels. Labels repel away from each other and away from the
    data points.
Depends: R (>= 3.0.0), ggplot2 (>= 2.2.0)
Imports: grid, Rcpp, scales (>= 0.3.0)
Suggests: knitr, rmarkdown, testthat, gridExtra, devtools, prettydoc
VignetteBuilder: knitr
License: GPL-3 | file LICENSE
URL: http://github.com/slowkow/ggrepel
BugReports: http://github.com/slowkow/ggrepel/issues
RoxygenNote: 6.0.1
LinkingTo: Rcpp
NeedsCompilation: yes
Packaged: 2018-05-09 13:53:18 UTC; slowikow
Author: Kamil Slowikowski [aut, cre] (<https://orcid.org/0000-0002-2843-6370>),
  Alicia Schep [ctb] (<https://orcid.org/0000-0002-3915-0618>),
  Sean Hughes [ctb],
  Saulius Lukauskas [ctb],
  Jean-Olivier Irisson [ctb] (<https://orcid.org/0000-0003-4920-3880>),
  Zhian N Kamvar [ctb] (<https://orcid.org/0000-0003-1458-7108>),
  Thompson Ryan [ctb] (<https://orcid.org/0000-0002-0450-8181>),
  Dervieux Christophe [ctb] (<https://orcid.org/0000-0003-4474-2498>),
  Yutani Hiroaki [ctb],
  Pierre Gramme [ctb]
Maintainer: Kamil Slowikowski <kslowikowski@gmail.com>
Repository: CRAN
Date/Publication: 2018-05-09 15:30:45 UTC
Built: R 3.4.1; x86_64-w64-mingw32; 2018-08-02 13:11:31 UTC; windows
Archs: x64
