# Generated by roxygen2: do not edit by hand

S3method(makeContent,labelrepelgrob)
S3method(makeContent,labelrepeltree)
S3method(makeContent,textrepelgrob)
S3method(makeContent,textrepeltree)
export(GeomLabelRepel)
export(GeomTextRepel)
export(geom_label_repel)
export(geom_text_repel)
import(ggplot2)
importFrom(Rcpp,evalCpp)
importFrom(grid,convertHeight)
importFrom(grid,convertWidth)
importFrom(grid,gList)
importFrom(grid,gTree)
importFrom(grid,gpar)
importFrom(grid,grobHeight)
importFrom(grid,grobName)
importFrom(grid,grobTree)
importFrom(grid,grobWidth)
importFrom(grid,grobX)
importFrom(grid,grobY)
importFrom(grid,is.grob)
importFrom(grid,is.unit)
importFrom(grid,makeContent)
importFrom(grid,resolveHJust)
importFrom(grid,resolveVJust)
importFrom(grid,roundrectGrob)
importFrom(grid,segmentsGrob)
importFrom(grid,setChildren)
importFrom(grid,textGrob)
useDynLib(ggrepel)
